==> glslang-13.0.0_1.darwin_20.arm64.tbz2: opt/local/lib/cmake/glslang/glslang-targets-macports.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "MacPorts".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "glslang::OSDependent" for configuration "MacPorts"
set_property(TARGET glslang::OSDependent APPEND PROPERTY IMPORTED_CONFIGURATIONS MACPORTS)
set_target_properties(glslang::OSDependent PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_MACPORTS "CXX"
  IMPORTED_LOCATION_MACPORTS "${_IMPORT_PREFIX}/lib/libOSDependent.a"
  )

list(APPEND _cmake_import_check_targets glslang::OSDependent )
list(APPEND _cmake_import_check_files_for_glslang::OSDependent "${_IMPORT_PREFIX}/lib/libOSDependent.a" )

# Import target "glslang::glslang" for configuration "MacPorts"
set_property(TARGET glslang::glslang APPEND PROPERTY IMPORTED_CONFIGURATIONS MACPORTS)
set_target_properties(glslang::glslang PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_MACPORTS "CXX"
  IMPORTED_LOCATION_MACPORTS "${_IMPORT_PREFIX}/lib/libglslang.a"
  )

list(APPEND _cmake_import_check_targets glslang::glslang )
list(APPEND _cmake_import_check_files_for_glslang::glslang "${_IMPORT_PREFIX}/lib/libglslang.a" )

# Import target "glslang::MachineIndependent" for configuration "MacPorts"
set_property(TARGET glslang::MachineIndependent APPEND PROPERTY IMPORTED_CONFIGURATIONS MACPORTS)
set_target_properties(glslang::MachineIndependent PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_MACPORTS "CXX"
  IMPORTED_LOCATION_MACPORTS "${_IMPORT_PREFIX}/lib/libMachineIndependent.a"
  )

list(APPEND _cmake_import_check_targets glslang::MachineIndependent )
list(APPEND _cmake_import_check_files_for_glslang::MachineIndependent "${_IMPORT_PREFIX}/lib/libMachineIndependent.a" )

# Import target "glslang::GenericCodeGen" for configuration "MacPorts"
set_property(TARGET glslang::GenericCodeGen APPEND PROPERTY IMPORTED_CONFIGURATIONS MACPORTS)
set_target_properties(glslang::GenericCodeGen PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_MACPORTS "CXX"
  IMPORTED_LOCATION_MACPORTS "${_IMPORT_PREFIX}/lib/libGenericCodeGen.a"
  )

list(APPEND _cmake_import_check_targets glslang::GenericCodeGen )
list(APPEND _cmake_import_check_files_for_glslang::GenericCodeGen "${_IMPORT_PREFIX}/lib/libGenericCodeGen.a" )

# Import target "glslang::glslang-default-resource-limits" for configuration "MacPorts"
set_property(TARGET glslang::glslang-default-resource-limits APPEND PROPERTY IMPORTED_CONFIGURATIONS MACPORTS)
set_target_properties(glslang::glslang-default-resource-limits PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_MACPORTS "CXX"
  IMPORTED_LOCATION_MACPORTS "${_IMPORT_PREFIX}/lib/libglslang-default-resource-limits.a"
  )

list(APPEND _cmake_import_check_targets glslang::glslang-default-resource-limits )
list(APPEND _cmake_import_check_files_for_glslang::glslang-default-resource-limits "${_IMPORT_PREFIX}/lib/libglslang-default-resource-limits.a" )

# Import target "glslang::OGLCompiler" for configuration "MacPorts"
set_property(TARGET glslang::OGLCompiler APPEND PROPERTY IMPORTED_CONFIGURATIONS MACPORTS)
set_target_properties(glslang::OGLCompiler PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_MACPORTS "CXX"
  IMPORTED_LOCATION_MACPORTS "${_IMPORT_PREFIX}/lib/libOGLCompiler.a"
  )

list(APPEND _cmake_import_check_targets glslang::OGLCompiler )
list(APPEND _cmake_import_check_files_for_glslang::OGLCompiler "${_IMPORT_PREFIX}/lib/libOGLCompiler.a" )

# Import target "glslang::glslang-standalone" for configuration "MacPorts"
set_property(TARGET glslang::glslang-standalone APPEND PROPERTY IMPORTED_CONFIGURATIONS MACPORTS)
set_target_properties(glslang::glslang-standalone PROPERTIES
  IMPORTED_LOCATION_MACPORTS "${_IMPORT_PREFIX}/bin/glslang"
  )

list(APPEND _cmake_import_check_targets glslang::glslang-standalone )
list(APPEND _cmake_import_check_files_for_glslang::glslang-standalone "${_IMPORT_PREFIX}/bin/glslang" )

# Import target "glslang::spirv-remap" for configuration "MacPorts"
set_property(TARGET glslang::spirv-remap APPEND PROPERTY IMPORTED_CONFIGURATIONS MACPORTS)
set_target_properties(glslang::spirv-remap PROPERTIES
  IMPORTED_LOCATION_MACPORTS "${_IMPORT_PREFIX}/bin/spirv-remap"
  )

list(APPEND _cmake_import_check_targets glslang::spirv-remap )
list(APPEND _cmake_import_check_files_for_glslang::spirv-remap "${_IMPORT_PREFIX}/bin/spirv-remap" )

# Import target "glslang::SPVRemapper" for configuration "MacPorts"
set_property(TARGET glslang::SPVRemapper APPEND PROPERTY IMPORTED_CONFIGURATIONS MACPORTS)
set_target_properties(glslang::SPVRemapper PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_MACPORTS "CXX"
  IMPORTED_LOCATION_MACPORTS "${_IMPORT_PREFIX}/lib/libSPVRemapper.a"
  )

list(APPEND _cmake_import_check_targets glslang::SPVRemapper )
list(APPEND _cmake_import_check_files_for_glslang::SPVRemapper "${_IMPORT_PREFIX}/lib/libSPVRemapper.a" )

# Import target "glslang::SPIRV" for configuration "MacPorts"
set_property(TARGET glslang::SPIRV APPEND PROPERTY IMPORTED_CONFIGURATIONS MACPORTS)
set_target_properties(glslang::SPIRV PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_MACPORTS "CXX"
  IMPORTED_LOCATION_MACPORTS "${_IMPORT_PREFIX}/lib/libSPIRV.a"
  )

list(APPEND _cmake_import_check_targets glslang::SPIRV )
list(APPEND _cmake_import_check_files_for_glslang::SPIRV "${_IMPORT_PREFIX}/lib/libSPIRV.a" )

# Import target "glslang::HLSL" for configuration "MacPorts"
set_property(TARGET glslang::HLSL APPEND PROPERTY IMPORTED_CONFIGURATIONS MACPORTS)
set_target_properties(glslang::HLSL PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_MACPORTS "CXX"
  IMPORTED_LOCATION_MACPORTS "${_IMPORT_PREFIX}/lib/libHLSL.a"
  )

list(APPEND _cmake_import_check_targets glslang::HLSL )
list(APPEND _cmake_import_check_files_for_glslang::HLSL "${_IMPORT_PREFIX}/lib/libHLSL.a" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> glslang-13.0.0_3.darwin_20.arm64.tbz2: opt/local/lib/cmake/glslang/glslang-targets-macports.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "MacPorts".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "glslang::glslang" for configuration "MacPorts"
set_property(TARGET glslang::glslang APPEND PROPERTY IMPORTED_CONFIGURATIONS MACPORTS)
set_target_properties(glslang::glslang PROPERTIES
  IMPORTED_LOCATION_MACPORTS "${_IMPORT_PREFIX}/lib/libglslang.13.0.0.dylib"
  IMPORTED_SONAME_MACPORTS "/opt/local/lib/libglslang.13.dylib"
  )

list(APPEND _cmake_import_check_targets glslang::glslang )
list(APPEND _cmake_import_check_files_for_glslang::glslang "${_IMPORT_PREFIX}/lib/libglslang.13.0.0.dylib" )

# Import target "glslang::glslang-default-resource-limits" for configuration "MacPorts"
set_property(TARGET glslang::glslang-default-resource-limits APPEND PROPERTY IMPORTED_CONFIGURATIONS MACPORTS)
set_target_properties(glslang::glslang-default-resource-limits PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_MACPORTS "CXX"
  IMPORTED_LOCATION_MACPORTS "${_IMPORT_PREFIX}/lib/libglslang-default-resource-limits.a"
  )

list(APPEND _cmake_import_check_targets glslang::glslang-default-resource-limits )
list(APPEND _cmake_import_check_files_for_glslang::glslang-default-resource-limits "${_IMPORT_PREFIX}/lib/libglslang-default-resource-limits.a" )

# Import target "glslang::glslang-standalone" for configuration "MacPorts"
set_property(TARGET glslang::glslang-standalone APPEND PROPERTY IMPORTED_CONFIGURATIONS MACPORTS)
set_target_properties(glslang::glslang-standalone PROPERTIES
  IMPORTED_LOCATION_MACPORTS "${_IMPORT_PREFIX}/bin/glslang"
  )

list(APPEND _cmake_import_check_targets glslang::glslang-standalone )
list(APPEND _cmake_import_check_files_for_glslang::glslang-standalone "${_IMPORT_PREFIX}/bin/glslang" )

# Import target "glslang::spirv-remap" for configuration "MacPorts"
set_property(TARGET glslang::spirv-remap APPEND PROPERTY IMPORTED_CONFIGURATIONS MACPORTS)
set_target_properties(glslang::spirv-remap PROPERTIES
  IMPORTED_LOCATION_MACPORTS "${_IMPORT_PREFIX}/bin/spirv-remap"
  )

list(APPEND _cmake_import_check_targets glslang::spirv-remap )
list(APPEND _cmake_import_check_files_for_glslang::spirv-remap "${_IMPORT_PREFIX}/bin/spirv-remap" )

# Import target "glslang::SPVRemapper" for configuration "MacPorts"
set_property(TARGET glslang::SPVRemapper APPEND PROPERTY IMPORTED_CONFIGURATIONS MACPORTS)
set_target_properties(glslang::SPVRemapper PROPERTIES
  IMPORTED_LOCATION_MACPORTS "${_IMPORT_PREFIX}/lib/libSPVRemapper.13.0.0.dylib"
  IMPORTED_SONAME_MACPORTS "/opt/local/lib/libSPVRemapper.13.dylib"
  )

list(APPEND _cmake_import_check_targets glslang::SPVRemapper )
list(APPEND _cmake_import_check_files_for_glslang::SPVRemapper "${_IMPORT_PREFIX}/lib/libSPVRemapper.13.0.0.dylib" )

# Import target "glslang::SPIRV" for configuration "MacPorts"
set_property(TARGET glslang::SPIRV APPEND PROPERTY IMPORTED_CONFIGURATIONS MACPORTS)
set_target_properties(glslang::SPIRV PROPERTIES
  IMPORTED_LOCATION_MACPORTS "${_IMPORT_PREFIX}/lib/libSPIRV.13.0.0.dylib"
  IMPORTED_SONAME_MACPORTS "/opt/local/lib/libSPIRV.13.dylib"
  )

list(APPEND _cmake_import_check_targets glslang::SPIRV )
list(APPEND _cmake_import_check_files_for_glslang::SPIRV "${_IMPORT_PREFIX}/lib/libSPIRV.13.0.0.dylib" )

# Import target "glslang::HLSL" for configuration "MacPorts"
set_property(TARGET glslang::HLSL APPEND PROPERTY IMPORTED_CONFIGURATIONS MACPORTS)
set_target_properties(glslang::HLSL PROPERTIES
  IMPORTED_LOCATION_MACPORTS "${_IMPORT_PREFIX}/lib/libHLSL.13.0.0.dylib"
  IMPORTED_SONAME_MACPORTS "/opt/local/lib/libHLSL.13.dylib"
  )

list(APPEND _cmake_import_check_targets glslang::HLSL )
list(APPEND _cmake_import_check_files_for_glslang::HLSL "${_IMPORT_PREFIX}/lib/libHLSL.13.0.0.dylib" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
